VideoCreationOptions class
VideoCreationOptions contains creation options for a video player.
- Annotations
Constructors
- VideoCreationOptions({required DataSource dataSource, required VideoViewType viewType})
-
Constructs an instance of VideoCreationOptions.
const
Properties
- dataSource → DataSource
-
The data source used to create the player.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- viewType → VideoViewType
-
The type of view to be used for displaying the video player
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited